@@ -202,7 +202,20 @@ def _bbox(bbox, resolution, offset):
     
     return LLON,BLAT,RLON,TLAT
 
+
 import geopandas as gpd
+
+def from_shp(data_variables=variables, start_time=start, end_time=end, shp=None, time_chunks=24):
+
+    gdf = gpd.GeoDataFrame.from_file(shp)
+    b = gdf.bounds
+    bbox = _bbox((b.loc[0]['minx'],b.loc[0]['miny'],b.loc[0]['maxx'],b.loc[0]['maxy']), 0.1, 0)
+
+    ds = open(data_variables, start_time, end_time, bbox, time_chunks)
+    
+    return ds
+
+
 from netCDF4 import Dataset,date2num,num2date
 import time
 from datetime import datetime, timedelta
@@ -272,7 +285,7 @@ def _creatspinc(value, data_vars, lats, lons, starttime, filename, resolution):
     
     
 
-def from_shp(data_variables=variables, start_time=start, end_time=end, shp=None, resolution='hourly', save_file='era5.nc', time_chunks=24):
+def to_netcdf(data_variables=variables, start_time=start, end_time=end, shp=None, resolution='hourly', save_file='era5.nc', time_chunks=24):
     
     gdf = gpd.GeoDataFrame.from_file(shp)
     b = gdf.bounds
